summaryrefslogtreecommitdiff
path: root/libs/ardour/session.cc
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2010-04-18 21:29:48 +0000
committerCarl Hetherington <carl@carlh.net>2010-04-18 21:29:48 +0000
commit895bad1dcd817cb8ad32dc255a90271edd6659fb (patch)
tree1385c5880cd9958bb2c6d189b6ff13ae4c43be74 /libs/ardour/session.cc
parentd9cac66b5d7f76a78b1ae1442a275516ef710bc9 (diff)
Make the session start/end location a single location (with start and end) rather than two separate ones. Fixes #1298.
git-svn-id: svn://localhost/ardour2/branches/3.0@6929 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'libs/ardour/session.cc')
-rw-r--r--libs/ardour/session.cc15
1 files changed, 6 insertions, 9 deletions
diff --git a/libs/ardour/session.cc b/libs/ardour/session.cc
index 11832646c8..9da481e7ce 100644
--- a/libs/ardour/session.cc
+++ b/libs/ardour/session.cc
@@ -712,9 +712,9 @@ Session::hookup_io ()
void
Session::playlist_length_changed ()
{
/* we can't just increase end_location->end() if pl->get_maximum_extent()
if larger. if the playlist used to be the longest playlist,
- and its now shorter, we have to decrease end_location->end(). hence,
+ and its now shorter, we have to decrease session_range_location->end(). hence,
we have to iterate over all diskstreams and check the
playlists currently in use.
*/
@@ -954,11 +954,8 @@ Session::handle_locations_changed (Locations::LocationList& locations)
set_loop = true;
}
- if (location->is_start()) {
- start_location = location;
- }
- if (location->is_end()) {
- end_location = location;
+ if (location->is_session_range()) {
+ _session_range_location = location;
}
}
@@ -2376,8 +2373,8 @@ Session::find_current_end ()
nframes_t max = get_maximum_extent ();
- if (max > end_location->end()) {
- end_location->set_end (max);
+ if (max > _session_range_location->end()) {
+ _session_range_location->set_end (max);
set_dirty();
DurationChanged(); /* EMIT SIGNAL */
}
@@ -712,9 +712,9 @@ Session::hookup_io ()
Session::playlist_length_changed ()
{
- /* we can't just increase end_location->end() if pl->get_maximum_extent()
+ /* we can't just increase session_range_location->end() if pl->get_maximum_extent()
if larger. if the playlist used to be the longest playlist,